@@ -5,7 +5,7 @@ use Moo::Role;
 
 use SHARYANTO::String::Util;
 
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 # can be changed to tab, for example
 has indent_character => (is => 'rw', default => sub {''});
@@ -56,7 +56,7 @@ Data::Sah::Compiler::TextResultRole - Role for compilers that produce text resul
 
 =head1 VERSION
 
-This document describes version 0.29 of Data::Sah::Compiler::TextResultRole (from Perl distribution Data-Sah), released on 2014-06-30.
+This document describes version 0.30 of Data::Sah::Compiler::TextResultRole (from Perl distribution Data-Sah), released on 2014-10-23.
 
 =head1 ATTRIBUTES
 
@@ -93,7 +93,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Sah>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Sah>.
 
 =head1 BUGS
 
@@ -105,11 +105,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
